<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

namespace Federator\Data\ActivityPub\Common;

class Collection extends APObject
{
    protected int $totalItems = 0;
    private string $first = '';
    private string $last = '';

    public function __construct()
    {
        parent::__construct('Collection');
        parent::addContext('https://www.w3.org/ns/activitystreams');
    }

    /**
     * convert internal state to php array
     * @return array<string,mixed>
     */
    public function toObject()
    {
        $return = parent::toObject();
        $return['type'] = 'Collection';
        if ($this->totalItems > 0) {
            $return['totalItems'] = $this->totalItems;
        }
        if ($this->first !== '') {
            $return['first'] = $this->first;
        }
        if ($this->last !== '') {
            $return['last'] = $this->last;
        }
        return $return;
    }

    /**
     * create object from json
     *
     * @param array<string,mixed> $json input json
     * @return bool true on success
     */
    public function fromJson($json)
    {
        $success = parent::fromJson($json);
        if (!$success) {
            return false;
        }
        if (array_key_exists('totalItems', $json)) {
            $this->totalItems = $json['totalItems'];
        }
        if (array_key_exists('first', $json)) {
            $this->first = $json['first'];
        }
        if (array_key_exists('last', $json)) {
            $this->last = $json['last'];
        }
        return true;
    }

    /**
     * set total items
     *
     * @param int $totalItems total items
     */
    public function setTotalItems(int $totalItems): void
    {
        $this->totalItems = $totalItems;
    }

    public function getTotalItems(): int
    {
        return $this->totalItems;
    }

    public function getFirst(): string
    {
        return $this->first;
    }

    public function setFirst(string $url): void
    {
        $this->first = $url;
    }

    public function setLast(string $url): void
    {
        $this->last = $url;
    }
}
